#!/usr/bin/env python

from kivy.app import App
from kivy.garden.cefpython import CEFBrowser

class Webmin(App):
    def build(self):
        return CEFBrowser(url="https://localhost:10000")
    
    
Webmin().run()


from setuptools import setup

setup(
    name='kivymin',
    version='0.1.0',    
    description='Kivy Webmin Gui',
    url='https://gitlab.com/onix-os/applications/kivy-webmin',
    author='Oytun OZDEMIR',
    author_email='info@oytun.org',
    license='BSD 2-clause',
    packages=['kivymin'],
    install_requires=['kivy',
                      'cefpython3',           
                      ],

    classifiers=[
        'Development Status :: 1 - Planning',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: BSD License',  
        'Operating System :: POSIX :: Linux',        
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
)
